body {
    width: 95vw;
    margin: auto;
    font-family: sans-serif;
    font-weight: normal;
}

button:focus, input:focus {
    outline:0;
}

input {
    border-radius: 10px;
    border: lightgrey outset 2px;
}

/* Custom Button Styles */
.btn {
    text-align: center;
    background-color: transparent;
    -webkit-transition : box-shadow 0.5s ease-out;
    -moz-transition : box-shadow 0.5s ease-out;
    -o-transition : box-shadow 0.5s ease-out;
    transition : box-shadow 0.5s ease-out;
}


.btn, .btn > * {
    cursor: pointer;
    background: white;
}

/* Show/Hide */
.decompressed {
    overflow: hidden;
    width: 100%;
    max-height: 1000px;
    transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -moz-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -ms-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -o-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -webkit-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
}

.compressed {
    overflow: hidden;
    width: 0px;
    max-height: 0px;
    transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -moz-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -ms-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -o-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
    -webkit-transition: width .5s ease-in-out, max-height 0.7s ease-in-out;
}

.show {
    display: block;
}

.hide {
    display: none !important;
}

.bold {
    font-weight: bold;
    color: green;
}

/* Divides Log Tags From Log Search Filters */
.divider {
    width: 80%;
    border-top: lightgrey solid 1px;
    margin: 15px auto;
}

/* Title And Legend */
#title {
    width: 100%;
    text-align: center;
    margin: 5px 0;
}

#legend {
    max-width: 100%;
    margin: 30px auto;
    display: grid;
}

#log-tags {
    display: flex;
    justify-content: space-evenly;
    align-items: center;
    align-content: space-evenly;
    padding-top: 5px;
    padding-bottom: 25px;
}

#filters-container {
    display: block;
    margin: 1em 0;
}

.log-tag {
    display: inline-flex;
}

#filters-btn {
    min-width: 130px;
    min-height: 25px;
    border-radius: 10px;
    border: lightgrey solid 1px;
}

#filters-controls, #search-container {
    display: block;
    margin: 10px auto;
    width: max-content;
}

#search-params {
    display: grid;
    grid-template-columns: auto auto auto;
    grid-gap: 10px 20px;
}

#search-controls {
    border: lightgrey solid 2px;
    border-radius: 15px;
    width: max-content;
    margin: 30px auto 0 auto;
}

#search {
    width: 300px;
    line-height: 25px;
    padding: 0 15px;
    border: none;
}

#go-btn {
    height: 25px;
    border: lightgrey solid;
    border-width: 0 0 0 2px;
    padding-left: 15px;
    margin-right: 12px;
}

#search-count {
    text-align: center;
    font: 400 11px system-ui;
    margin-top: 10px;
    color: green;
    font-weight: bold;
    font-style: italic;
}

#filters-controls {
    padding-bottom: 10px;
}

#filters {
    border: lightgrey solid;
    border-width: 2px 0px;
    overflow: hidden;
    height: fit-content;
    margin: auto;
    padding: 15px 0;
}

#reset-btn {
    float: left;
    margin: 15px 0px;
    width: 80px;
    height: 25px;
    border-radius: 15px;
}

/* Code Block Frames */
#code-blocks {
    width: 50%;
    overflow: auto;
    margin: 0 15px;
    padding: 0 25px;
    float: right;
    border-left: lightgrey 1px ridge;
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    max-height: 80vh;
}

object.code {
    width: 100%;
    height: 100%;
    border: none;
    margin: 0;
    padding: 0;
}

.code-block {
    margin: 10px;
    border: lightgrey 2px solid;
    border-radius: 5px;
}

.code-block-controls {
    position: sticky;
    top: 0;
    float: right;
    width: 100%;
    background-color: rgba(127, 127, 127);
    text-align: center;
    padding: 5px 0;
}

.close-code {
    background-color: darkred;
    color: white;
    float: right;
    margin-right: 10px;
    border-radius: 5px;
}

.code {
    padding: 10px;
    overflow: auto;
    margin: 0 10px;
    max-height: 400px;
}

.filepath {
    color: white;
    font-style: italic;
    display: inline-block;
    width: 93%;
    overflow: hidden;
    overflow-wrap: break-word;
}


/* Log Entries */
#log-entries {
    display: grid;
}

.log-entries {
    width: 100%;
    margin: auto;
}

.log-entry {
    height: fit-content;
    min-width: 80%;
}

.log-entry > .log-row {
    display: grid;
        grid-template-columns: 35px 300px auto repeat(var(--log-entry-btns), minmax(auto, 80px));
}

.log-row {
    margin: 3px 0;
}

.log-row > div {
    padding: 0px 3px;
}

.item-container {
    border-right: lightgrey solid 2px;
}

.item-container > button {
    border: none;
    background: transparent;
}

.func {
    text-align: left;
    padding: 0px 15px !important;
    overflow: hidden;
    text-overflow: ellipsis;
}

.preview {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    text-indent: 13px;
}

.exp-btn::before {
    position: relative;
    top: 3pt;
    left: 2pt;
    content: "";
    display: inline-block;
    width: 0.4em;
    height: 0.4em;
    border-right: 0.2em solid black;
    border-top: 0.2em solid black;
}

.exp-btn:hover::before {
    border-color: green;
}

.hide-logs::before {
    transform: rotate(45deg);
    margin-right: 0.5em;
    transition: transform 0.8s;
    -moz-transition: transform 0.3s;
    -ms-transition: transform 0.3s;
    -o-transition: transform 0.3s;
    -webkit-transition: transform 0.3s;
}

.show-logs::before {
    transform: rotate(135deg);
    margin-right: 0.5em;
    transition: transform 0.3s;
    -moz-transition: transform 0.3s;
    -ms-transition: transform 0.3s;
    -o-transition: transform 0.3s;
    -webkit-transition: transform 0.3s;
}

.no-exp {
    opacity: 0.5;
    text-align: center;
    cursor: default;
}

.log-block > pre, .log-block > div {
    border: lightgrey solid 2px;
    margin: 2px auto;
    border-radius: 10px;
    padding: 15px;
    overflow: auto;
    max-height: 400px !important;
    white-space: pre-wrap;
    overflow-wrap: break-word;
}

.log-block-container {
    margin: auto;
    padding: 0 10px;
}

/* Switch Toggle */
.fancy-checkbox {
    display: grid;
    grid-template-columns: auto auto;
    grid-gap: 10px;
    justify-content: start;
}

.switch {
  position: relative;
  display: inline-block;
  width: 44px;
  height: 16px;
}

.switch input {
  opacity: 0;
  width: 0;
  height: 0;
}

.slider {
  position: absolute;
  cursor: pointer;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  -webkit-transition: .4s;
  transition: .4s;
}

.slider:before {
  position: absolute;
  content: "";
  height: 13px;
  width: 13px;
  left: 2px;
  bottom: 2px;
  background-color: white;
  -webkit-transition: .4s;
  transition: .4s;
}

input:not(:checked) + .slider {
    background-color: #ccc !important;
}

input:checked + .slider {
  background-color: #2196F3;
}

input:focus + .slider {
  box-shadow: 0 0 1px #2196F3;
}

input:checked + .slider:before {
  -webkit-transform: translateX(26px);
  -ms-transform: translateX(26px);
  transform: translateX(26px);
}

/* Rounded sliders */
.slider.round {
  border-radius: 34px;
}

.slider.round:before {
  border-radius: 50%;
}
